@@ -19,9 +19,7 @@
 #include <queue>
 
 #include <ignition/common/Console.hh>
-#include <ignition/common/Filesystem.hh>
 #include <ignition/common/SignalHandler.hh>
-#include <ignition/common/StringUtils.hh>
 #include <ignition/common/SystemPaths.hh>
 #include <ignition/common/Util.hh>
 
@@ -30,12 +28,9 @@
 #include "ignition/gui/Application.hh"
 #include "ignition/gui/config.hh"
 #include "ignition/gui/Dialog.hh"
-#include "ignition/gui/Helpers.hh"
 #include "ignition/gui/MainWindow.hh"
 #include "ignition/gui/Plugin.hh"
 
-#include "ignition/transport/TopicUtils.hh"
-
 namespace ignition
 {
   namespace gui
@@ -87,20 +82,15 @@ using namespace gui;
 
 /////////////////////////////////////////////////
 Application::Application(int &_argc, char **_argv, const WindowType _type)
-  : QGuiApplication(_argc, _argv), dataPtr(new ApplicationPrivate)
+  : QApplication(_argc, _argv), dataPtr(new ApplicationPrivate)
 {
   igndbg << "Initializing application." << std::endl;
 
-  this->setOrganizationName("Ignition");
-  this->setOrganizationDomain("ignitionrobotics.org");
-  this->setApplicationName("Ignition GUI");
-
   // Configure console
   common::Console::SetPrefix("[GUI] ");
 
   // QML engine
   this->dataPtr->engine = new QQmlApplicationEngine();
-  this->dataPtr->engine->addImportPath(qmlQrcImportPath());
 
   // Install signal handler for graceful shutdown
   this->dataPtr->signalHandler.AddCallback(
@@ -181,7 +171,7 @@ QQmlApplicationEngine *Application::Engine() const
 }
 
 /////////////////////////////////////////////////
-Application *gui::App()
+Application *ignition::gui::App()
 {
   return qobject_cast<Application *>(qGuiApp);
 }
@@ -224,50 +214,24 @@ bool Application::LoadConfig(const std::string &_config)
     return false;
   }
 
-  std::string configFull = _config;
-
-  // Check if the passed in config file exists.
-  // (If the default config path doesn't exist yet, it's expected behavior.
-  // It will be created the first time the user presses "Save configuration".)
-  if (!common::exists(configFull) && (configFull != this->DefaultConfigPath()))
-  {
-    // If not, then check environment variable
-    std::string configPathEnv;
-    common::env("GZ_GUI_RESOURCE_PATH", configPathEnv);
-
-    if (!configPathEnv.empty())
-    {
-      std::vector<std::string> parentPaths = common::Split(configPathEnv, ':');
-      for (auto parentPath : parentPaths)
-      {
-        std::string tempPath = common::joinPaths(parentPath, configFull);
-        if (common::exists(tempPath))
-        {
-          configFull = tempPath;
-          break;
-        }
-      }
-    }
-  }
-
   // Use tinyxml to read config
   tinyxml2::XMLDocument doc;
-  auto success = !doc.LoadFile(configFull.c_str());
+  auto success = !doc.LoadFile(_config.c_str());
   if (!success)
   {
     // We do not show an error message if the default config path doesn't exist
     // yet. It's expected behavior, it will be created the first time the user
     // presses "Save configuration".
-    if (configFull != this->DefaultConfigPath())
+    if (_config != this->DefaultConfigPath())
     {
-      ignerr << "Failed to load file [" << configFull << "]: XMLError"
+      ignerr << "Failed to load file [" << _config << "]: XMLError"
              << std::endl;
     }
 
     return false;
   }
 
-  ignmsg << "Loading config [" << configFull << "]" << std::endl;
+  ignmsg << "Loading config [" << _config << "]" << std::endl;
 
   // Clear all previous plugins
   auto plugins = this->dataPtr->mainWin->findChildren<Plugin *>();
@@ -305,89 +269,12 @@ bool Application::LoadConfig(const std::string &_config)
     this->dataPtr->windowConfig.MergeFromXML(std::string(printer.CStr()));
 
     // Closing behavior.
-    if (auto defaultExitActionElem =
-      winElem->FirstChildElement("default_exit_action"))
-    {
-      ExitAction action{ExitAction::CLOSE_GUI};
-      const auto value = common::lowercase(defaultExitActionElem->GetText());
-      if (value == "shutdown_server")
-      {
-        action = ExitAction::SHUTDOWN_SERVER;
-      }
-      else if (value != "close_gui" && !value.empty())
-      {
-        ignwarn << "Value '" << value << "' of <default_exit_action> is "
-                << "invalid. Allowed values are CLOSE_GUI and SHUTDOWN_SERVER. "
-                << "Selecting CLOSE_GUI as fallback." << std::endl;
-      }
-      this->dataPtr->mainWin->SetDefaultExitAction(action);
-    }
-
-    // Dialog on exit
     if (auto dialogOnExitElem = winElem->FirstChildElement("dialog_on_exit"))
     {
       bool showDialogOnExit{false};
       dialogOnExitElem->QueryBoolText(&showDialogOnExit);
       this->dataPtr->mainWin->SetShowDialogOnExit(showDialogOnExit);
     }
-
-    if (auto dialogOnExitOptionsElem =
-      winElem->FirstChildElement("dialog_on_exit_options"))
-    {
-      if (auto promptElem =
-        dialogOnExitOptionsElem->FirstChildElement("prompt_text"))
-      {
-        this->dataPtr->mainWin->SetDialogOnExitText(
-          QString::fromStdString(promptElem->GetText()));
-      }
-      if (auto showShutdownElem =
-        dialogOnExitOptionsElem->FirstChildElement("show_shutdown_button"))
-      {
-        bool showShutdownButton{false};
-        showShutdownElem->QueryBoolText(&showShutdownButton);
-        this->dataPtr->mainWin->SetExitDialogShowShutdown(showShutdownButton);
-      }
-      if (auto showCloseGuiElem =
-        dialogOnExitOptionsElem->FirstChildElement("show_close_gui_button"))
-      {
-        bool showCloseGuiButton{false};
-        showCloseGuiElem->QueryBoolText(&showCloseGuiButton);
-        this->dataPtr->mainWin->SetExitDialogShowCloseGui(showCloseGuiButton);
-      }
-      if (auto shutdownTextElem =
-        dialogOnExitOptionsElem->FirstChildElement("shutdown_button_text"))
-      {
-        this->dataPtr->mainWin->SetExitDialogShutdownText(
-          QString::fromStdString(shutdownTextElem->GetText()));
-      }
-      if (auto closeGuiTextElem =
-        dialogOnExitOptionsElem->FirstChildElement("close_gui_button_text"))
-      {
-        this->dataPtr->mainWin->SetExitDialogCloseGuiText(
-          QString::fromStdString(closeGuiTextElem->GetText()));
-      }
-    }
-
-    // Server control service topic
-    std::string serverControlService{"/server_control"};
-    auto serverControlElem =
-      winElem->FirstChildElement("server_control_service");
-    if (nullptr != serverControlElem && nullptr != serverControlElem->GetText())
-    {
-      serverControlService = transport::TopicUtils::AsValidTopic(
-        serverControlElem->GetText());
-    }
-
-    if (serverControlService.empty())
-    {
-      ignerr << "Failed to create valid server control service" << std::endl;
-    }
-    else
-    {
-      ignmsg << "Using server control service [" << serverControlService
-             << "]" << std::endl;
-      this->dataPtr->mainWin->SetServerControlService(serverControlService);
-    }
   }
 
   this->ApplyConfig();
@@ -452,7 +339,7 @@ bool Application::LoadPlugin(const std::string &_filename,
   }
 
   // Go over all plugin names and get the first one that implements the
-  // gui::Plugin interface
+  // ignition::gui::Plugin interface
   plugin::PluginPtr commonPlugin;
   std::shared_ptr<gui::Plugin> plugin{nullptr};
   for (auto pluginName : pluginNames)
@@ -461,7 +348,7 @@ bool Application::LoadPlugin(const std::string &_filename,
     if (!commonPlugin)
       continue;
 
-    plugin = commonPlugin->QueryInterfaceSharedPtr<gui::Plugin>();
+    plugin = commonPlugin->QueryInterfaceSharedPtr<ignition::gui::Plugin>();
     if (plugin)
       break;
   }
@@ -482,7 +369,7 @@ bool Application::LoadPlugin(const std::string &_filename,
   if (!plugin)
   {
     ignerr << "Failed to load plugin [" << _filename <<
-              "] : couldn't get [gui::Plugin] interface."
+              "] : couldn't get [ignition::gui::Plugin] interface."
            << std::endl;
     return false;
   }
@@ -500,9 +387,6 @@ bool Application::LoadPlugin(const std::string &_filename,
   else
     plugin->Load(_pluginElem);
 
-  if (nullptr == plugin->CardItem())
-    return false;
-
   // Store plugin in queue to be added to the window
   this->dataPtr->pluginsToAdd.push(plugin);
 
@@ -537,12 +421,6 @@ std::shared_ptr<Plugin> Application::PluginByName(
   return nullptr;
 }
 
-/////////////////////////////////////////////////
-bool Application::CreateMainWindow()
-{
-  return this->InitializeMainWindow();
-}
-
 /////////////////////////////////////////////////
 bool Application::InitializeMainWindow()
 {
