@@ -156,19 +156,32 @@ TEST(ConversionsTest, Time)
 
   // Msgs to common to msgs
   {
-    msgs::Time t;
+    ignition::msgs::Time t;
     t.set_sec(s);
     t.set_nsec(ns);
-
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
     auto nt = convert(convert(t));
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
     EXPECT_DOUBLE_EQ(nt.sec(), t.sec());
     EXPECT_DOUBLE_EQ(nt.nsec(), t.nsec());
   }
 
   // Common to msgs to common
   {
+#ifndef _WIN32
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#endif
     common::Time t(s, ns);
     EXPECT_EQ(convert(convert(t)), t);
+#ifndef _WIN32
+# pragma GCC diagnostic pop
+#endif
   }
 }
 
