@@ -30,6 +30,8 @@
 #include <ignition/plugin/Register.hh>
 #include <ignition/common/MeshManager.hh>
 
+#include <ignition/rendering/Capsule.hh>
+
 #include <ignition/math/Vector2.hh>
 #include <ignition/math/Vector3.hh>
 
@@ -691,6 +693,24 @@ rendering::GeometryPtr SceneManager::LoadGeometry(const msgs::Geometry &_msg,
     scale.Y() = scale.X();
     scale.Z() = _msg.cylinder().length();
   }
+  else if (_msg.has_capsule())
+  {
+    auto capsule = this->scene->CreateCapsule();
+    capsule->SetRadius(_msg.capsule().radius());
+    capsule->SetLength(_msg.capsule().length());
+    geom = capsule;
+
+    scale.X() = _msg.capsule().radius() * 2;
+    scale.Y() = scale.X();
+    scale.Z() = _msg.capsule().length() + scale.X();
+  }
+  else if (_msg.has_ellipsoid())
+  {
+    geom = this->scene->CreateSphere();
+    scale.X() = _msg.ellipsoid().radii().x() * 2;
+    scale.Y() = _msg.ellipsoid().radii().y() * 2;
+    scale.Z() = _msg.ellipsoid().radii().z() * 2;
+  }
   else if (_msg.has_plane())
   {
     geom = this->scene->CreatePlane();
@@ -729,8 +749,8 @@ rendering::GeometryPtr SceneManager::LoadGeometry(const msgs::Geometry &_msg,
     // Assume absolute path to mesh file
     descriptor.meshName = _msg.mesh().filename();
 
-    common::MeshManager* meshManager =
-        common::MeshManager::Instance();
+    ignition::common::MeshManager* meshManager =
+        ignition::common::MeshManager::Instance();
     descriptor.mesh = meshManager->Load(descriptor.meshName);
     geom = this->scene->CreateMesh(descriptor);
 
@@ -883,11 +903,11 @@ void IgnRenderer::Render()
   // update and render to texture
   this->dataPtr->camera->Update();
 
-  if (gui::App())
+  if (ignition::gui::App())
   {
-    gui::App()->sendEvent(
-        gui::App()->findChild<MainWindow *>(),
-        new events::Render());
+    ignition::gui::App()->sendEvent(
+        ignition::gui::App()->findChild<ignition::gui::MainWindow *>(),
+        new gui::events::Render());
   }
 }
 
@@ -1059,37 +1079,19 @@ void IgnRenderer::BroadcastRightClick()
 }
 
 /////////////////////////////////////////////////
-std::string IgnRenderer::Initialize()
+void IgnRenderer::Initialize()
 {
   if (this->initialized)
-    return std::string();
-
-  // Currently only support one engine at a time
-  rendering::RenderEngine *engine{nullptr};
-  auto loadedEngines = rendering::loadedEngines();
-
-  // Load engine if there's no engine yet
-  if (loadedEngines.empty())
-  {
-    std::map<std::string, std::string> params;
-    params["useCurrentGLContext"] = "1";
-    engine = rendering::engine(this->engineName, params);
-  }
-  else
-  {
-    if (loadedEngines.front() != this->engineName)
-    {
-      ignwarn << "Failed to load engine [" << this->engineName
-              << "]. Using engine [" << loadedEngines.front()
-              << "], which is already loaded. Currently only one engine is "
-              << "supported at a time." << std::endl;
-    }
-    engine = rendering::engine(loadedEngines.front());
-  }
+    return;
 
+  std::map<std::string, std::string> params;
+  params["useCurrentGLContext"] = "1";
+  auto engine = rendering::engine(this->engineName, params);
   if (!engine)
   {
-    return "Engine [" + this->engineName + "] is not supported";
+    ignerr << "Engine [" << this->engineName << "] is not supported"
+           << std::endl;
+    return;
   }
 
   // Scene
@@ -1101,11 +1103,6 @@ std::string IgnRenderer::Initialize()
     scene->SetAmbientLight(this->ambientLight);
     scene->SetBackgroundColor(this->backgroundColor);
   }
-  else
-  {
-    return "Currently only one plugin providing a 3D scene is supported at a "
-            "time.";
-  }
 
   auto root = scene->RootVisual();
 
@@ -1135,7 +1132,6 @@ std::string IgnRenderer::Initialize()
   this->dataPtr->rayQuery = this->dataPtr->camera->Scene()->CreateRayQuery();
 
   this->initialized = true;
-  return std::string();
 }
 
 /////////////////////////////////////////////////
@@ -1207,12 +1203,6 @@ RenderThread::RenderThread()
   RenderWindowItemPrivate::threads << this;
 }
 
-/////////////////////////////////////////////////
-void RenderThread::SetErrorCb(std::function<void(const QString&)> _cb)
-{
-  this->errorCb = _cb;
-}
-
 /////////////////////////////////////////////////
 void RenderThread::RenderNext()
 {
@@ -1221,12 +1211,7 @@ void RenderThread::RenderNext()
   if (!this->ignRenderer.initialized)
   {
     // Initialize renderer
-    auto loadingError = this->ignRenderer.Initialize();
-    if (!loadingError.empty())
-    {
-      this->errorCb(QString::fromStdString(loadingError));
-      return;
-    }
+    this->ignRenderer.Initialize();
   }
 
   // check if engine has been successfully initialized
@@ -1244,24 +1229,18 @@ void RenderThread::RenderNext()
 /////////////////////////////////////////////////
 void RenderThread::ShutDown()
 {
-  if (this->context && this->surface)
-    this->context->makeCurrent(this->surface);
+  this->context->makeCurrent(this->surface);
 
   this->ignRenderer.Destroy();
 
-  if (this->context)
-  {
-    this->context->doneCurrent();
-    delete this->context;
-  }
+  this->context->doneCurrent();
+  delete this->context;
 
   // schedule this to be deleted only after we're done cleaning up
-  if (this->surface)
-    this->surface->deleteLater();
+  this->surface->deleteLater();
 
   // Stop event processing, move the thread to GUI and make sure it is deleted.
-  if (this->ignRenderer.initialized)
-    this->moveToThread(QGuiApplication::instance()->thread());
+  this->moveToThread(QGuiApplication::instance()->thread());
 }
 
 
@@ -1290,8 +1269,9 @@ TextureNode::TextureNode(QQuickWindow *_window)
 #if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
   this->texture = this->window->createTextureFromId(0, QSize(1, 1));
 #else
+  void * nativeLayout;
   this->texture = this->window->createTextureFromNativeObject(
-      QQuickWindow::NativeObjectTexture, nullptr, 0, QSize(1, 1),
+      QQuickWindow::NativeObjectTexture, &nativeLayout, 0, QSize(1, 1),
       QQuickWindow::TextureIsOpaque);
 #endif
   this->setTexture(this->texture);
@@ -1541,8 +1521,6 @@ void Scene3D::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
            << "Render window will not be created" << std::endl;
     return;
   }
-  renderWindow->SetErrorCb(std::bind(&Scene3D::SetLoadingError, this,
-      std::placeholders::_1));
 
   if (this->title.empty())
     this->title = "3D Scene";
@@ -1626,17 +1604,11 @@ void Scene3D::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
 }
 
 /////////////////////////////////////////////////
-void RenderWindowItem::OnHovered(const math::Vector2i &_hoverPos)
+void RenderWindowItem::OnHovered(const ignition::math::Vector2i &_hoverPos)
 {
   this->dataPtr->renderThread->ignRenderer.NewHoverEvent(_hoverPos);
 }
 
-/////////////////////////////////////////////////
-void RenderWindowItem::SetErrorCb(std::function<void(const QString&)> _cb)
-{
-  this->dataPtr->renderThread->SetErrorCb(_cb);
-}
-
 /////////////////////////////////////////////////
 void RenderWindowItem::mousePressEvent(QMouseEvent *_e)
 {
@@ -1739,19 +1711,6 @@ void Scene3D::OnFocusWindow()
   renderWindow->forceActiveFocus();
 }
 
-/////////////////////////////////////////////////
-QString Scene3D::LoadingError() const
-{
-  return this->loadingError;
-}
-
-/////////////////////////////////////////////////
-void Scene3D::SetLoadingError(const QString &_loadingError)
-{
-  this->loadingError = _loadingError;
-  this->LoadingErrorChanged();
-}
-
 // Register this plugin
-IGNITION_ADD_PLUGIN(Scene3D,
-                    gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gui::plugins::Scene3D,
+                    ignition::gui::Plugin)
