@@ -85,15 +85,6 @@ void WorldControl::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
     return;
   }
 
-  // If no elements were set, show all buttons. We assume that the user never
-  // wants to hide all buttons. This happens for example when the plugin is
-  // inserted from the menu.
-  if (_pluginElem->NoChildren())
-  {
-    this->PluginItem()->setProperty("showPlay", true);
-    this->PluginItem()->setProperty("showStep", true);
-  }
-
   // World name from window, to construct default topics and services
   std::string worldName;
   auto worldNames = gui::worldNames();
@@ -133,6 +124,14 @@ void WorldControl::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
 
     this->dataPtr->controlService = "/world/" + worldName + "/control";
   }
+  this->dataPtr->controlService = transport::TopicUtils::AsValidTopic(
+      this->dataPtr->controlService);
+
+  if (this->dataPtr->controlService.empty())
+  {
+    ignerr << "Failed to create valid control service for world [" << worldName
+           << "]" << std::endl;
+  }
 
   ignmsg << "Using world control service [" << this->dataPtr->controlService
          << "]" << std::endl;
@@ -194,6 +193,7 @@ void WorldControl::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
     statsTopic = "/world/" + worldName + "/stats";
   }
 
+  statsTopic = transport::TopicUtils::AsValidTopic(statsTopic);
   if (!statsTopic.empty())
   {
     // Subscribe to world_stats
@@ -207,6 +207,11 @@ void WorldControl::LoadConfig(const tinyxml2::XMLElement *_pluginElem)
       ignmsg << "Listening to stats on [" << statsTopic << "]" << std::endl;
     }
   }
+  else
+  {
+    ignerr << "Failed to create valid topic for world [" << worldName << "]"
+           << std::endl;
+  }
 }
 
 /////////////////////////////////////////////////
@@ -222,7 +227,7 @@ void WorldControl::ProcessMsg()
 }
 
 /////////////////////////////////////////////////
-void WorldControl::OnWorldStatsMsg(const msgs::WorldStatistics &_msg)
+void WorldControl::OnWorldStatsMsg(const ignition::msgs::WorldStatistics &_msg)
 {
   std::lock_guard<std::recursive_mutex> lock(this->dataPtr->mutex);
 
@@ -233,14 +238,14 @@ void WorldControl::OnWorldStatsMsg(const msgs::WorldStatistics &_msg)
 /////////////////////////////////////////////////
 void WorldControl::OnPlay()
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [this](const msgs::Boolean &/*_rep*/, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [this](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
   {
     if (_result)
       QMetaObject::invokeMethod(this, "playing");
   };
 
-  msgs::WorldControl req;
+  ignition::msgs::WorldControl req;
   req.set_pause(false);
   this->dataPtr->pause = false;
   this->dataPtr->node.Request(this->dataPtr->controlService, req, cb);
@@ -249,14 +254,14 @@ void WorldControl::OnPlay()
 /////////////////////////////////////////////////
 void WorldControl::OnPause()
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [this](const msgs::Boolean &/*_rep*/, const bool _result)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [this](const ignition::msgs::Boolean &/*_rep*/, const bool _result)
   {
     if (_result)
       QMetaObject::invokeMethod(this, "paused");
   };
 
-  msgs::WorldControl req;
+  ignition::msgs::WorldControl req;
   req.set_pause(true);
   this->dataPtr->pause = true;
   this->dataPtr->node.Request(this->dataPtr->controlService, req, cb);
@@ -271,17 +276,17 @@ void WorldControl::OnStepCount(const unsigned int _steps)
 /////////////////////////////////////////////////
 void WorldControl::OnStep()
 {
-  std::function<void(const msgs::Boolean &, const bool)> cb =
-      [](const msgs::Boolean &/*_rep*/, const bool /*_result*/)
+  std::function<void(const ignition::msgs::Boolean &, const bool)> cb =
+      [](const ignition::msgs::Boolean &/*_rep*/, const bool /*_result*/)
   {
   };
 
-  msgs::WorldControl req;
+  ignition::msgs::WorldControl req;
   req.set_pause(this->dataPtr->pause);
   req.set_multi_step(this->dataPtr->multiStep);
   this->dataPtr->node.Request(this->dataPtr->controlService, req, cb);
 }
 
 // Register this plugin
-IGNITION_ADD_PLUGIN(WorldControl,
-                    gui::Plugin)
+IGNITION_ADD_PLUGIN(ignition::gui::plugins::WorldControl,
+                    ignition::gui::Plugin)
